@@ -18,8 +18,8 @@ pub struct Event {
 impl Event {
     /// Creates a new event if the start and end date strings have a correct format
     pub fn new(name: String, start_date: &str, end_date: &str) -> Result<Self, String> {
-        let start_date = Event::parse_date(start_date)?;
-        let end_date = Event::parse_date(end_date)?;
+        let start_date = parse_date(start_date)?;
+        let end_date = parse_date(end_date)?;
         Ok(Self {
             name,
             start_date,
@@ -30,8 +30,8 @@ impl Event {
     /// Updates an event with a new name and start and end date. If start or end date have an invalid format,
     /// return false.
     pub fn update(&mut self, name: String, start_date: &str, end_date: &str) -> bool {
-        let start_date = Event::parse_date(start_date);
-        let end_date = Event::parse_date(end_date);
+        let start_date = parse_date(start_date);
+        let end_date = parse_date(end_date);
         if matches!(end_date, Ok(_)) && matches!(start_date, Ok(_)) {
             self.start_date = start_date.unwrap();
             self.end_date = end_date.unwrap();
@@ -44,18 +44,7 @@ impl Event {
 
     /// Checks if a given date is valid
     pub fn is_date_valid(date: &str) -> bool {
-        Self::parse_date(date).is_ok()
-    }
-
-    /// Parses a date string into a NaiveDate
-    fn parse_date(date: &str) -> Result<NaiveDate, String> {
-        let possible_fmts = [EVENT_DATE_FORMAT, "%Y-%_m-%_d", "%d.%m.%Y", "%_d.%_m.%Y"];
-        for fmt in possible_fmts {
-            if let Ok(parsed_date) = chrono::NaiveDate::parse_from_str(date, fmt) {
-                return Ok(parsed_date);
-            }
-        }
-        Err(format!("Cannot parse string {}", date))
+        parse_date(date).is_ok()
     }
 
     /// Returns the event start date as a string
@@ -67,11 +56,27 @@ impl Event {
     pub fn end_date_as_string(&self) -> String {
         self.end_date.format(EVENT_DATE_FORMAT).to_string()
     }
+
+    /// Returns whether a date is within the event
+    pub fn contains(&self, date: &NaiveDate) -> bool {
+        self.start_date <= *date && *date <= self.end_date
+    }
+}
+
+/// Parses a date string into a NaiveDate
+pub fn parse_date(date: &str) -> Result<NaiveDate, String> {
+    let possible_fmts = [EVENT_DATE_FORMAT, "%Y-%_m-%_d", "%d.%m.%Y", "%_d.%_m.%Y"];
+    for fmt in possible_fmts {
+        if let Ok(parsed_date) = chrono::NaiveDate::parse_from_str(date, fmt) {
+            return Ok(parsed_date);
+        }
+    }
+    Err(format!("Cannot parse string {}", date))
 }
 
 mod tests {
     #[cfg(test)]
-    use super::Event;
+    use super::*;
 
     #[test]
     fn test_parse() {
@@ -86,15 +91,12 @@ mod tests {
 
         for (input, result) in test_cases {
             assert_eq!(
-                Event::parse_date(input)
-                    .unwrap()
-                    .format("%Y-%m-%d")
-                    .to_string(),
+                parse_date(input).unwrap().format("%Y-%m-%d").to_string(),
                 result
             );
         }
 
-        assert!(Event::parse_date("invalid").is_err());
+        assert!(parse_date("invalid").is_err());
     }
 
     #[test]
@@ -127,4 +129,15 @@ mod tests {
         assert_eq!(event.start_date_as_string(), "2021-09-16");
         assert_eq!(event.end_date_as_string(), "2021-09-17");
     }
+
+    #[test]
+    fn test_contains() {
+        let event = Event::new("test".to_string(), "2021-09-14", "2021-09-16").unwrap();
+
+        assert!(event.contains(&NaiveDate::from_ymd(2021, 9, 14)));
+        assert!(event.contains(&NaiveDate::from_ymd(2021, 9, 15)));
+        assert!(event.contains(&NaiveDate::from_ymd(2021, 9, 16)));
+        assert!(!event.contains(&NaiveDate::from_ymd(2021, 9, 13)));
+        assert!(!event.contains(&NaiveDate::from_ymd(2021, 9, 17)));
+    }
 }
